!function(e,o){"object"==typeof exports&&"object"==typeof module?module.exports=o():"function"==typeof define&&define.amd?define("buildbot-wsgi-dashboards",[],o):"object"==typeof exports?exports["buildbot-wsgi-dashboards"]=o():e["buildbot-wsgi-dashboards"]=o()}("undefined"!=typeof self?self:this,function(){return function(e){var o={};function r(t){if(o[t])return o[t].exports;var n=o[t]={i:t,l:!1,exports:{}};return e[t].call(n.exports,n,n.exports,r),n.l=!0,n.exports}return r.m=e,r.c=o,r.d=function(e,o,t){r.o(e,o)||Object.defineProperty(e,o,{enumerable:!0,get:t})},r.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},r.t=function(e,o){if(1&o&&(e=r(e)),8&o)return e;if(4&o&&"object"==typeof e&&e&&e.__esModule)return e;var t=Object.create(null);if(r.r(t),Object.defineProperty(t,"default",{enumerable:!0,value:e}),2&o&&"string"!=typeof e)for(var n in e)r.d(t,n,function(o){return e[o]}.bind(null,n));return t},r.n=function(e){var o=e&&e.__esModule?function(){return e.default}:function(){return e};return r.d(o,"a",o),o},r.o=function(e,o){return Object.prototype.hasOwnProperty.call(e,o)},r.p="",r(r.s=0)}([function(e,o,r){angular.module("wsgi_dashboards",["ui.router","buildbot_config","guanlecoja.ui"]),r(1)},function(e,o){angular.module("wsgi_dashboards").config(["$stateProvider","glMenuServiceProvider","config",class WsgiDashboardsState{constructor(e,o,r){for(var t=0,n=Array.from(r.plugins.wsgi_dashboards);t<n.length;t++){var a=n[t],i=a.name,u=a.caption;null==u&&(u=_.capitalize(i)),null==a.order&&(a.order=5),o.addGroup({name:i,caption:u,icon:a.icon,order:a.order});var s={group:i,caption:u},l={controller:"wsgiDashboardsController",templateUrl:"wsgi_dashboards/".concat(i,"/index.html"),name:i,url:"/".concat(i),data:s};e.state(l)}}}]).controller("wsgiDashboardsController",["$scope","$state",class WsgiDashboardsController{constructor(e,o){}}])}])});
//# sourceMappingURL=scripts.js.map